@@ -30,6 +30,13 @@ subst_dict = {'PREFIX': prefix}
 subst_dict.update((attrname, getattr(defs, attrname)) for attrname in
     ('EMAILFILTER_%s' % item for item in ('BUFSIZE', 'HOSTNAME', 'PORT')))
 del prefix, defs
+# Extra hack to allow different formatting of port number when installing
+# as root, also encloses other variable values in quotes for safety
+for key in subst_dict:
+    if (os.getuid() == 0) and (key == 'EMAILFILTER_PORT'):
+        subst_dict[key] = '$((%s + $UID))' % subst_dict[key]
+    else:
+        subst_dict[key] = '"%s"' % subst_dict[key]
 
 def patch_file(filename):
     pathname = os.path.join(binpath, filename)
@@ -40,7 +47,7 @@ def patch_file(filename):
         f.close()
     for varname, value in subst_dict.iteritems():
         oldstr = '%s=""' % varname
-        newstr = '%s="%s"' % (varname, value)
+        newstr = '%s=%s' % (varname, value)
         if oldstr in s:
             print "Setting", varname, "to", value
             s = s.replace(oldstr, newstr)
